::: jaxspec.analysis.results.FitResult
    options:
      members:
        - converged
        - samples_haiku
        - samples_flat
        - photon_flux
        - energy_flux
        - luminosity
        - plot_ppc
        - plot_corner
        - table
      show_root_heading: true